<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package    Featured
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2017, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function featured_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', bloginfo( 'pingback_url' ), '">';
	}
}
add_action( 'wp_head', 'featured_pingback_header' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the body element.
 * @return array
 */
function featured_body_classes( $classes ) {

	// Adds a class of multi-author to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'multi-author';
	}

	// Adds a class for the container style.
	$container = get_theme_mod( 'featured_container_style', 'fullwidth' );
	if ( $container == 'fullwidth' ) {
		$classes[] = 'full-width-container';
	} elseif ( $container == 'boxed' ) {
		$classes[] = 'boxed-container';
	} else {
		$classes[] = 'framed-container';
	}

	// Layout on archive & search page.
	if ( is_home() || is_archive() || is_search() ) {

		$archive_layouts = get_theme_mod( 'featured_archive_layouts', '2c-l' );

		if ( $archive_layouts === '2c-l' || $archive_layouts === '2c-r' || $archive_layouts === '1c' || $archive_layouts === '1c-n' ) {
			$classes[] = 'layout-list';
		} else {
			$classes[] = 'layout-' . $archive_layouts;
		}
	}

	if ( is_page_template( 'page-templates/home.php' ) ) {
		$classes[] = 'layout-2c-l-m';
	}

	return $classes;
}
add_filter( 'body_class', 'featured_body_classes' );

/**
 * Adds custom classes to the array of post classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the post element.
 * @return array
 */
function featured_post_classes( $classes ) {

	// Adds a class if a post hasn't a thumbnail.
	if ( ! has_post_thumbnail() ) {
		$classes[] = 'no-post-thumbnail';
	}

	// Replace hentry class with entry.
	$classes[] = 'entry';

	return $classes;
}
add_filter( 'post_class', 'featured_post_classes' );

/**
 * Remove 'hentry' from post_class()
 */
function featured_remove_hentry( $class ) {
	$class = array_diff( $class, array( 'hentry' ) );
	return $class;
}
add_filter( 'post_class', 'featured_remove_hentry' );

/**
 * Change the excerpt more string.
 *
 * @since  1.0.0
 * @param  string  $more
 * @return string
 */
function featured_excerpt_more( $more ) {
	return '&hellip;';
}
add_filter( 'excerpt_more', 'featured_excerpt_more' );

/**
 * Filter the except length to 20 words.
 */
function featured_custom_excerpt_length( $length ) {
	return 24;
}
add_filter( 'excerpt_length', 'featured_custom_excerpt_length', 999 );

/**
 * Remove theme-layouts meta box on attachment and bbPress post type.
 *
 * @since 1.0.0
 */
function featured_remove_theme_layout_metabox() {
	remove_post_type_support( 'attachment', 'theme-layouts' );

	// bbPress
	remove_post_type_support( 'forum', 'theme-layouts' );
	remove_post_type_support( 'topic', 'theme-layouts' );
	remove_post_type_support( 'reply', 'theme-layouts' );
}
add_action( 'init', 'featured_remove_theme_layout_metabox', 11 );

/**
 * Add post type 'post' support for the Simple Page Sidebars plugin.
 *
 * @since  1.0.0
 */
function featured_page_sidebar_plugin() {
	if ( class_exists( 'Simple_Page_Sidebars' ) ) {
		add_post_type_support( 'post', 'simple-page-sidebars' );
	}
}
add_action( 'init', 'featured_page_sidebar_plugin' );

/**
 * Register custom contact info fields.
 *
 * @since  1.0.0
 * @param  array $contactmethods
 * @return array
 */
function featured_contact_info_fields( $contactmethods ) {
	$contactmethods['twitter']     = esc_html__( 'Twitter URL', 'featured' );
	$contactmethods['facebook']    = esc_html__( 'Facebook URL', 'featured' );
	$contactmethods['gplus']       = esc_html__( 'Google Plus URL', 'featured' );
	$contactmethods['instagram']   = esc_html__( 'Instagram URL', 'featured' );
	$contactmethods['pinterest']   = esc_html__( 'Pinterest URL', 'featured' );
	$contactmethods['linkedin']    = esc_html__( 'Linkedin URL', 'featured' );

	return $contactmethods;
}
add_filter( 'user_contactmethods', 'featured_contact_info_fields' );

/**
 * Extend archive title
 *
 * @since  1.0.0
 */
function featured_extend_archive_title( $title ) {
	if ( is_category() ) {
		$title = single_cat_title( '', false );
	} elseif ( is_tag() ) {
		$title = single_tag_title( '', false );
	} elseif ( is_author() ) {
		$title = get_the_author();
	} elseif ( is_search() ) {
		$title = sprintf( esc_html__( 'Search Results for: %s', 'featured' ), '<span>' . get_search_query() . '</span>' );
	} elseif ( is_404() ) {
		$title = esc_html__( '404 Not Found!', 'featured' );
	} else {
		$title = esc_html__( 'Latest News', 'featured' );
	}
	return $title;
}
add_filter( 'get_the_archive_title', 'featured_extend_archive_title' );

/**
 * Customize tag cloud widget
 *
 * @since  1.0.0
 */
function featured_customize_tag_cloud( $args ) {
	$args['largest']  = 12;
	$args['smallest'] = 12;
	$args['unit']     = 'px';
	$args['number']   = 20;
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'featured_customize_tag_cloud' );

/**
 * Modifies the theme layout on attachment pages.
 *
 * @since  1.0.0
 */
function featured_mod_theme_layout( $layout ) {

	// Change the layout to Full Width on Attachment page.
	if ( is_attachment() && wp_attachment_is_image() ) {
		$post_layout = get_post_layout( get_queried_object_id() );
		if ( 'default' === $post_layout ) {
			$layout = '1c';
		}
	}

	// Layout on archive & search page.
	if ( is_home() || is_archive() || is_search() ) {
		$archive_layouts = get_theme_mod( 'featured_archive_layouts', '2c-l' );

		$layout = $archive_layouts;

		if ( $archive_layouts === '2c-l-g' || $archive_layouts === '2c-l-m' ) {
			$layout = '2c-l';
		} elseif ( $archive_layouts === '2c-r-g' || $archive_layouts === '2c-r-m' ) {
			$layout = '2c-r';
		} elseif ( $archive_layouts === '1c-g' || $archive_layouts === '1c-m' ) {
			$layout = '1c';
		} elseif ( $archive_layouts === '1c-g-n' ) {
			$layout = '1c-n';
		}
	}

	// Layout on home template
	if ( is_page_template( 'page-templates/home.php' ) ) {
		$layout = '2c-l';
	}

	// Layout on home builder template
	if ( is_page_template( 'page-templates/home-builder.php' ) ) {
		$layout = '1c';
	}

	return $layout;
}
add_filter( 'theme_mod_theme_layout', 'featured_mod_theme_layout', 15 );
